
export function isNotificationSupported() {

    let result = false;

    if ("Notification" in window) {
        result = true;
    }

    return result;
}

export function isServiceWorkerSupported() {

    let result = false;

    if (navigator && 'serviceWorker' in navigator && navigator.serviceWorker && typeof navigator.serviceWorker !== 'undefined') {
        result = true;
    }

    return result;
}

export async function getSubscription() {

    let subscription = null;

    if (isNotificationSupported() && isServiceWorkerSupported()) {
        let serviceWorkerRegistration = await navigator.serviceWorker.ready;
        if (serviceWorkerRegistration && serviceWorkerRegistration.pushManager) {
            subscription = await serviceWorkerRegistration.pushManager.getSubscription();
        }
    }

    return subscription;
}

export async function subscribe(userVisibleOnly, publicKey) {

    let subscription = null;

    if (isServiceWorkerSupported()) {

        let serviceWorkerRegistration = await navigator.serviceWorker.ready;

        const options = {
            userVisibleOnly: userVisibleOnly,
            applicationServerKey: urlBase64ToUint8Array(publicKey),
        };

        subscription = await serviceWorkerRegistration.pushManager.subscribe(options);
    }

    return subscription;
}

export async function unsubscribe() {

    let subscription = await getSubscription();
    if (subscription != null) {
        let result = await subscription.unsubscribe();
        if (!result) {
            subscription = null;
        }
    }

    return subscription;
}

export function urlBase64ToUint8Array(base64String) {
    var padding = '='.repeat((4 - base64String.length % 4) % 4);
    var base64 = (base64String + padding)
        .replace(/\-/g, '+')
        .replace(/_/g, '/');

    var rawData = window.atob(base64);
    var outputArray = new Uint8Array(rawData.length);

    for (var i = 0; i < rawData.length; i++) {
        outputArray[i] = rawData.charCodeAt(i);
    }
    return outputArray;
}