
export function isNotificationSupported() {

    let result = false;

    if ("Notification" in window) {
        result = true;
    }

    return result;
}

export function isServiceWorkerSupported() {

    let result = false;

    if (navigator && 'serviceWorker' in navigator && navigator.serviceWorker && typeof navigator.serviceWorker !== 'undefined') {
        result = true;
    }

    return result;
}

export async function getServiceWorkerRegistration() {

    let registration = null;

    if (isServiceWorkerSupported()) {
        registration = await navigator.serviceWorker.getRegistration();
    }

    return registration;
}

export async function getNotifications() {

    let notifications = [];

    if (isNotificationSupported() && isServiceWorkerSupported()) {

        let registration = await getServiceWorkerRegistration();

        if (registration && typeof registration.getNotifications !== "undefined") {
            notifications = await registration.getNotifications();
        }
    }

    return notifications;
}

export function getPermission() { // default, granted, denied, unsupported

    let result = 'unsupported';

    if (isNotificationSupported()) {
        result = Notification.permission;
    }

    return result;
}

export async function askNotificationPermission() {

    let result = getPermission();

    if (result == 'default') {
        try {
            result = await Notification.requestPermission();
        }
        catch (ex) {

            let waitUser = true;

            Notification.requestPermission((permission) => {
                result = permission;
                waitUser = false;
            });

            while (waitUser) {
                await new Promise(resolve => {
                    return setTimeout(resolve, 1000)
                });
            }
        }
    }

    return result;
}

export async function showNotification(title, body, badge, icon, image, tag) {

    let options = {
        body: body,
        silent: false,
        vibrate: [ 300, 300 ],
    }

    if (badge)
        options.badge = badge;

    if (icon)
        options.icon = icon;

    if (image)
        options.image = image;

    if (tag)
    {
        options.tag = tag;
        options.renotify = true;
    }

    let registration = await getServiceWorkerRegistration();
    if (registration && registration != null) {
        registration.showNotification(title, options)
    }
}

export async function closeNotification(tag) {
    if (isNotificationSupported()) {

        let notifications = await getNotifications();
        notifications.forEach(function (notification) {

            if (tag == null || tag == notification.tag) {
                notification.close();
            }
        });
    }
}

export async function closeNotificationStartsWith(tag) {
    if (isNotificationSupported()) {

        let notifications = await getNotifications();
        notifications.forEach(function (notification) {

            if (notification.tag == null && tag == null) {
                notification.close();
            }
            else if (notification.tag != null) {

                if (notification.tag.startsWith(tag)) {
                    notification.close();
                }
            }
        });
    }
}